@@ -14,6 +14,11 @@ setMethodS3("stop", "default", function(...) {
   base::stop(...);
 })
 
+parse <- function(...) UseMethod("parse");
+parse.default <- function(...) {
+  base::parse(...);
+}
+
 ############################################################################
 # HISTORY:
 # 2005-08-01
