@@ -36,7 +36,7 @@ setMethodS3("print", "RspString", function(x, ...) {
   s <- sprintf("%s:", class(x)[1L]);
   s <- c(s, sprintf("Content type: %s", getAttribute(x, "type", NA)));
   s <- c(s, sprintf("Language: %s", getAttribute(x, "language", NA)));
-  metadata <- getMetadata(x);
+  metadata <- getMetadata(x, local=FALSE);
   if (length(metadata) > 0L) {
     metadata <- unlist(metadata, use.names=TRUE);
     s <- c(s, sprintf("Metadata '%s': %s", names(metadata), metadata));
@@ -146,17 +146,25 @@ setMethodS3("getType", "RspString", function(object, default=NA, as=c("text", "I
 #   @seeclass
 # }
 #*/#########################################################################
-setMethodS3("getMetadata", "RspString", function(object, name=NULL, ...) {
+setMethodS3("getMetadata", "RspString", function(object, name=NULL, default=NULL, local=FALSE, ...) {
   res <- getAttribute(object, "metadata", default=list());
+  if (!local) {
+    isLocal <- is.element(names(res), "source");
+    res <- res[!isLocal];
+  }
   if (!is.null(name)) {
-    res <- res[[name]];
+    if (is.element(name, names(res))) {
+      res <- res[[name]];
+    } else {
+      res <- default;
+    }
   }
   res;
 }, protected=TRUE)
 
 
 setMethodS3("setMetadata", "RspString", function(object, metadata=NULL, name, value, ...) {
-  data <- getMetadata(object);
+  data <- getMetadata(object, local=TRUE);
 
   if (!is.null(metadata)) {
     for (name in names(metadata)) {
