@@ -16,7 +16,7 @@ untils <- setdiff(untils, "*")
 for (kk in seq_along(untils)) {
   until <- untils[kk]
   verbose && enter(verbose, sprintf("Until #%d ('%s') of %d", kk, until, length(untils)))
-  s0 <- rcompile(file=pathname, until=until, as="RspString")
+  s0 <- rcompile(file=pathname, until=until, output=RspString())
   d0 <- parse(s0, until=until)
   stopifnot(inherits(d0, "RspDocument"))
   s1 <- asRspString(d0)
